from time import sleep

from Utils import Utils
import os

## Classe Menu
# Affichage principal de l'application du squelette
# Toutes les interactions utilisateur sont effectuées ici
from UtilsGit import UtilsGit


class Menu:
    auteur_en_cours = 0

    ## Constructeur, permet de lancer le 1er menu
    def __init__(self):
        # obligatoire à faire au début
        Utils.initialise_mongo()
        # si les auteurs n'existent pas on les créée
        Utils.creer_auteur_si_besoin()
        self.menu_de_base()

    ##  1er menu affiché et proposé à l'utilisateur
    #    Permet de choisir un "compte"
    #    (Version spéciale pour le squelette)
    def menu_de_base(self):
        os.system('clear')
        # temporaire, juste pour la création du squelette
        print("Choisir votre numéro d'auteur")
        print("1 : Auteur 1")
        print("2 : Auteur 2")
        print("3 : Auteur 3")
        print("Votre choix : ")
        choix = (input())

        # choix spécial (et masqué) permettant de réinitialiser le squelette
        if choix == 'p':
            Utils.tout_peter()
            self.menu_de_base()
        if choix.isdigit():
            auteur = Utils.switch_auteur(int(choix))
            if auteur != "Auteur inconnu":

                if Utils.presence_utilisateur(auteur):
                    self.auteur_en_cours = auteur
                    self.menu_des_actions()
        else:
            print("Erreur de saisie")
            sleep(1)
            self.menu_de_base()

    ##    Menu affiché une fois un compte valide sélectionné
    def menu_des_actions(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Management des contenus : ")
        print("0 : Personnels")
        print("1 : Tiers")
        print("2 : En Cours")
        print("3 : En Banque")
        print("Autres options : ")
        print("4 : Mise à jour des contenus")
        print("5 : Gestion des évaluations")
        print("q : Deconnexion")
        print("Votre choix : ")
        choix = (input())
        if choix == 'q':
            self.menu_de_base()
        elif choix.isdigit():
            self.switch_actions(int(choix))
        else:
            print("Choix non disponible, appuyer sur q pour revenir au menu : ")
            input()
            self.menu_des_actions()

    ##  Permet de récupérer l'action désirée par l'utilisateur
    def switch_actions(self, choix):
        if 0 <= choix <= 3:
            if choix == 0:
                self.menu_contenus_personnels()
            elif choix == 1:
                self.menu_contenus_tiers()
            elif choix == 2:
                self.menu_contenus_en_cours()
            elif choix == 3:
                self.menu_contenus_banque()
        elif choix == 4:
            self.menu_de_maj()
        elif choix == 5:
            self.gestion_des_evaluations()
        else:
            print("Choix non disponible, appuyer sur q pour revenir au menu : ")
            input()
            self.menu_des_actions()

    ## Menu des contenus personnels
    def menu_contenus_personnels(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Menu des contenus personnels :")
        questions = Utils.get_contenus(self.auteur_en_cours, True)
        print(f"Voici les contenus que vous avez ({str(questions.count())}) : ")

        if questions.count() > 0:
            self.afficher_contenus(questions)
        print("Actions disponibles : ")
        print("n : Ajouter un contenu")
        print("q : quitter le menu des contenus personnels")
        if questions.count() > 0:
            self.afficher_contenus(questions)
            print("c : consulter le détail d'un contenu")
            # print("m : modifier un contenu")
            print("s : supprimer un contenu")
            print("Pour manipuler un contenu, Saisir le numero du contenu puis l'action désirée (par ex : 1c)")

        choix = input()
        # Choix de création de contenu
        if choix == 'n':
            print("Selectionner le fichier à charger")
            print("1 : Contenu1")
            print("2 : Contenu2")
            print("q : Revenir en arrière")
            print("Votre choix : ")
            choix = (input())
            if choix == 'q':
                self.menu_contenus_personnels()
            elif choix.isdigit() and 1 <= int(choix) <= 2:
                Utils.ajouter_contenu("Contenu" + str(choix), self.auteur_en_cours)
                print("Le contenu ", choix, " a été ajouté dans vos contenus personnels")
                sleep(2)
                self.menu_contenus_personnels()
            else:
                print("Choix non disponible, appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_personnels()
        elif choix == 'q':
            self.menu_des_actions()
        if len(choix) > 1:
            id = int(choix[:len(choix) - 1])
            action = choix[len(choix) - 1:]
            # Choix de consultation de contenu
            if action == 'c':
                os.system('clear')
                print("Bonjour ", self.auteur_en_cours)
                print("Vous consultez le contenu ", id)
                Utils.changer_version(id, 0, "master")
                version_choisie = Utils.get_version_courante(id)
                if Utils.get_version_courante(id) != 1:
                    print("Je choisis la version que je veux : (entre 1 et", Utils.get_version_courante(id), ")")
                    version_choisie = int(input())
                    print("Je veux charger la version ", choix)
                    # commitVersion = Utils.getCommitPourUneVersion(choix, contenu)
                    Utils.changer_version(id, choix)
                else:
                    version_courante = int(Utils.get_version_courante(id))
                    Utils.changer_version(id, version_courante)
                print("Voici le détail de votre contenu n°", id)
                Utils.consulter_un_contenu(id, self.auteur_en_cours)
                # Utils.affichage(Utils.get_chemin_du_contenu(id))
                if Utils.get_version_courante(id) != version_choisie:
                    print("Vous n'etes pas dans la version courante donc ne pouvez pas modifier le contenu")
                    print("Appuyez sur q pour quitter")
                    input()
                    self.menu_contenus_personnels()
                else:
                    print("Appuyez sur m pour modifier le fichier ou sur q pour quitter")
                    choix = input()
                    if choix == 'q':
                        Utils.detruire_fichier_tmp(id, self.auteur_en_cours)
                        self.menu_contenus_personnels()
                    elif choix == 'm':
                        self.modifier_contenu(id)
                        print("Modification ouverte sur ce contenu")
                        print("Appuyer sur q pour revenir en arrière : ")
                        input()
                        self.menu_contenus_en_cours()
                    else:
                        print("Choix non disponible, appuyer sur q pour revenir en arrière : ")
                        input()
                        self.menu_contenus_personnels()
            # Choix de suppression de contenu
            elif action == 's':
                if Utils.existe_en_tiers(id):
                    Utils.renier_contenu(id)
                    print("le contenu ", id, "a été supprimé. Vous n'en êtes plus le propriétaire")
                else:
                    Utils.supprimer_contenu(id)
                    print("le contenu ", id, "a été supprimé définitivement")
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_personnels()
            else:
                print("Action non disponible, appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_personnels()

    ## Affichage des contenus personnels
    def afficher_contenus(self, contenu):

        for elt in contenu:
            print("id : ", elt["id"], "nom :", elt["fichier"], " - v", elt["versionEnCours"]["numero"], " - du",
                  elt["versionEnCours"]["date"])

    ## Modification d'un contenu (dans ce cas, on incrémente l'indice de fin de fichier)
    def modifier_contenu(self, id_contenu):

        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        print("Vous avez choisi de modifier le contenu ", id_contenu)
        Utils.modifier_contenu(id_contenu, self.auteur_en_cours)
        print(
            "Un contenu en cours a été créé, appuyer sur c pour accéder aux contenus en cours ou q pour revenir au menu des actions")
        choix = input()
        if choix == 'c':
            self.menu_contenus_en_cours()
        else:
            self.menu_des_actions()

    ## Menu des contenus tiers
    def menu_contenus_tiers(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Menu des contenus tiers :")
        print(f"Voici les contenus tiers que vous avez {len(Utils.get_contenus_tiers(self.auteur_en_cours))}: ")

        if len(Utils.get_contenus_tiers(self.auteur_en_cours)):
            for (id, version) in Utils.get_contenus_tiers(self.auteur_en_cours):
                self.afficher_contenus_tiers(
                    Utils.get_contenu_avec_id_et_version(int(id['contenu']), int(version['version'])),
                    int(version['version']))

        print("Actions disponibles : ")
        print("q : revenir au menu des actions")

        if len(Utils.get_contenus_tiers(self.auteur_en_cours)):

            print("c : consulter le détail d'un tiers")
            print("s : supprimer un tiers")
            print("Pour manipuler un contenu, Saisir le numero du contenu puis l'action désirée (par ex : 1c)")
            choix = input()
            if len(choix) == 1:
                self.menu_des_actions()
            else:
                id = int(choix[:len(choix) - 1])
                action = choix[len(choix) - 1:]
                if action == 'c':
                    os.system('clear')
                    print("Bonjour ", self.auteur_en_cours)
                    Utils.changer_version(id, 0, "master")
                    version_tiers = Utils.get_version_tiers_avec_id(id, self.auteur_en_cours)
                    print("Voici le détail de votre tiers n°", id, "dans sa version ", version_tiers)
                    Utils.changer_version(id, version_tiers)
                    Utils.consulter_un_contenu(id, self.auteur_en_cours)
                    # Utils.affichage(Utils.get_chemin_du_contenu(id))
                    if version_tiers != Utils.get_version_courante(id):
                        print("Vous n'etes pas dans la version courante donc ne pouvez pas modifier le contenu")
                        print("Appuyez sur q pour quitter")
                        input()
                        self.menu_contenus_tiers()
                    else:
                        print("Appuyez sur m pour modifier le fichier ou sur q pour quitter")
                        choix = input()
                        if choix == 'q':
                            Utils.detruire_fichier_tmp(id, self.auteur_en_cours)
                            self.menu_contenus_tiers()
                        elif choix == 'm':
                            self.modifier_contenu(id)
                            print("Modification ouverte sur ce tiers")
                            print("Appuyer sur c pour aller aux contenus tiers ou sur q pour revenir en arrière : ")
                            choix = input()
                            if choix == 'q':
                                self.menu_contenus_tiers()
                            else:
                                self.menu_contenus_en_cours()
                        else:
                            print("Choix non disponible, appuyer sur q pour revenir en arrière : ")
                            input()
                            self.menu_contenus_tiers()
                elif action == 's':
                    Utils.supprimer_tiers(id, self.auteur_en_cours,
                                          Utils.get_version_tiers_avec_id(id, self.auteur_en_cours))
                    if not Utils.existe_en_tiers(id):
                        Utils.supprimer_contenu(id)
                        print("Contenu Tiers supprimé définitivement")
                    else:
                        print("Contenu Tiers supprimé")
                    print("Appuyer sur q pour revenir en arrière : ")
                    input()
                    self.menu_contenus_tiers()
                else:
                    print("Action inconnue, appuyer sur q pour revenir au menu : ")
                    input()
                    self.menu_contenus_tiers()
        else:
            input()
            self.menu_des_actions()

    ## Fonction d'affichage des contenus tiers
    def afficher_contenus_tiers(self, contenu, version):
        print("id :", contenu["id"], "auteur :", contenu["auteur"], " - nom :", contenu["fichier"], " - v",
              version, " - du",
              contenu["versionEnCours"]["date"])

    ## Menu des contenus en cours
    def menu_contenus_en_cours(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Menu des contenus en cours :")
        contenus = Utils.get_contenus_en_cours(self.auteur_en_cours)
        print(f"Voici les contenus en cours que vous avez  ({contenus.count()}): ")

        if contenus.count() > 0:
            self.afficher_contenus_en_cours(contenus)

        print("Actions disponibles : ")
        print("q : revenir au menu des actions")

        if contenus.count() > 0:
            self.afficher_contenus_en_cours(contenus)

            print("c : pour consulter le contenu")
            print("s : pour supprimer le contenu")
            print("v : pour valider la modification du contenu (sous réserve)")
            print("n : pour créer un nouveau contenu")
            print("Entrer l'id du contenu en cours, puis une lettre d'action (ou directement q pour quitter)")

        choix = input()

        if choix == 'q':
            self.menu_des_actions()
        elif len(choix) > 1:
            id = int(choix[:len(choix) - 1])
            action = choix[len(choix) - 1:]
            if action == 'c':
                Utils.changer_version(id, 0, Utils.get_branche_contenu_en_cours(id))
                Utils.consulter_un_contenu(id, self.auteur_en_cours)
                print("Appuyez sur m pour modifier le fichier ou sur q pour quitter")
                choix = input()
                if choix == 'q':
                    self.menu_contenus_en_cours()
                elif choix == 'm':
                    Utils.modifier_contenu(id, self.auteur_en_cours, True)
                    print("Appuyer sur q pour revenir en arrière : ")
                    input()
                    self.menu_contenus_en_cours()
                else:
                    print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
                    input()
                    self.menu_contenus_en_cours()
            elif action == 's':
                Utils.supprimer_contenu_en_cours(id)
                print("Contenu en cours ", id, " supprimé")
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_en_cours()
            elif action == 'v':
                self.valider_modification(id)
                print("La demande de validation du contenu a été effectuée")
                # Si le contenu validé est d'origine personnelle on peut supprimer le en cours (sinon on le conserve)
                if not Utils.is_tiers_auteur(self.auteur_en_cours, id) or Utils.is_anonyme(id):
                    Utils.supprimer_contenu_en_cours(int(id))

                print("Appuyer sur q pour revenir en arriere : ")
                input()
                self.menu_contenus_en_cours()
            elif action == 'n':
                print("Is favori :", Utils.is_tiers_auteur(self.auteur_en_cours, id))
                if not Utils.is_tiers_auteur(self.auteur_en_cours, id):
                    contenu_associe = Utils.get_id_contenu_associe_a_un_en_cours(int(id))
                    chemin = Utils.get_chemin_du_contenu(contenu_associe)
                    Utils.creer_nouveau_contenu(chemin,
                                                self.auteur_en_cours, id)
                else:
                    print("Vous n'avez pas le droit de faire directement cette action sur un contenu tiers")
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_en_cours()
        else:
            print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
            input()
            self.menu_contenus_en_cours()

    ## affichage des contenus en cours
    def afficher_contenus_en_cours(self, contenu):

        for elt in contenu:
            print("id Modif :", elt["idContenuEC"], "auteur original :", elt["auteur"], " - id Original :",
                  elt["reference"],
                  "version original", elt["version"], " date modif ", elt["date"], end='')
            if Utils.is_en_cours_demande(elt["idContenuEC"], self.auteur_en_cours):
                print("(demande de publication en cours sur ce contenu)")
            else:
                print("\r")

    ## Menu des contenus en banque
    def menu_contenus_banque(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Menu des contenus en banque :")
        print(
            f"Il y a  {len(Utils.get_contenus_tiers(self.auteur_en_cours))} contenus présents  (excepteption des votres): ")
        questions = Utils.get_contenus(self.auteur_en_cours, False)
        print("La banque possède actuellement", questions.count(), " contenu(s)")

        if questions.count() > 0:
            self.afficher_contenus_banque(questions)

        print("Actions disponibles : ")
        print("q : revenir au menu des actions")

        if questions.count() > 0:
            print("c : pour consulter le contenu")
            print("t : pour mettre un contenu dans ses contenu tiers")
            print("Entrer l'id du contenu en cours, puis une lettre d'action (ou directement q pour quitter)")

        choix = input()

        if choix == 'q':
            self.menu_des_actions()
        elif len(choix) > 1:
            id = int(choix[:len(choix) - 1])
            action = choix[len(choix) - 1:]
            if action == 'c':
                Utils.changer_version(id, 0, "master")
                version_choisie = Utils.get_version_courante(id)
                if Utils.get_version_courante(id) != 1:
                    print("Je choisis la version que je veux : (entre 1 et", Utils.get_version_courante(id), ")")
                    version_choisie = int(input())
                    print("Je veux charger la version ", choix)
                    # commitVersion = Utils.getCommitPourUneVersion(choix, contenu)
                    Utils.changer_version(id, choix)
                Utils.consulter_un_contenu(id, self.auteur_en_cours)
                print("Appuyer sur t pour vous approprier le contenu ou sur q pour revenir en arrière : ")
                choix = input()
                Utils.detruire_fichier_tmp(id, self.auteur_en_cours)
                if choix == 't':
                    Utils.mettre_contenu_en_tiers(id, self.auteur_en_cours, version_choisie)
                    print("Le contenu ", id, 'est a présent disponible dans vos contenus tiers')
                    print("Appuyer sur q pour aller aux contenus tiers : ")
                    input()
                    self.menu_contenus_tiers()
                else:
                    self.menu_contenus_banque()
            elif action == 't':
                Utils.mettre_contenu_en_tiers(id, self.auteur_en_cours)
                print("Le contenu ", id, 'est a orésent disponible dans vos contenus tiers')
                print("Appuyer sur q pour aller aux contenus tiers : ")
                input()
                self.menu_contenus_tiers()
            else:
                print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_des_actions()

    ## Fonction d'affichage des contenus en banque
    def afficher_contenus_banque(self, contenu):

        for elt in contenu:
            print("id :", elt["id"], "auteur :", elt["auteur"], " - nom :", elt["fichier"], " - v",
                  elt["versionEnCours"]["numero"], " - du",
                  elt["versionEnCours"]["date"])

    # Fonction de gestion d'une demande de validation d'un contenu en cours
    def valider_modification(self, idContenuEnCours):

        # on récupère l'auteur et l'id du contenu "de base" associé à la modif
        auteur = Utils.get_auteur_contenu_en_cours(idContenuEnCours)
        idContenu = Utils.get_id_contenu_associe_a_un_en_cours(idContenuEnCours)
        branche = Utils.get_branche_contenu_en_cours(idContenuEnCours)

        # si modification d'un contenu personnel ou d'un contenu anonyme, elle est faite directement
        if auteur == self.auteur_en_cours or Utils.is_anonyme(idContenu):
            chemin = Utils.get_chemin_du_contenu(idContenu)
            Utils.maj_contenu(chemin, idContenu, branche)
        # Dans le cas contraire, on bascule vers une demande de publication de contenu
        else:
            Utils.demande_publication(idContenu, idContenuEnCours, self.auteur_en_cours, auteur)

    ## Fonction globale de gestion des évaluations
    def gestion_des_evaluations(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print(f"Vous possédez {len(Utils.get_contenus_tiers(self.auteur_en_cours))} évaluations créées: ")

        evaluations = Utils.get_evaluations(self.auteur_en_cours)
        if evaluations.count() > 0:
            self.afficher_evaluations(evaluations)

        print("Actions disponibles : ")
        print("q : revenir au menu des actions")
        print("n : créer une évaluation")

        if evaluations.count() > 0:
            print("c : pour consulter l'évaluation")
            print("s : pour supprimer l'évaluation")
            print("Entrer l'id de l'évaluation, puis une lettre d'action (ou directement q pour quitter)")

        choix = input()
        if choix == 'q':
            self.menu_des_actions()
        elif choix == 'n':
            self.creerEvaluation()
            print("Evaluation créée")
            print("Appuyer sur q pour revenir en arrière : ")
            input()
            self.gestion_des_evaluations()
        elif len(choix) > 1:
            id = int(choix[:len(choix) - 1])
            action = choix[len(choix) - 1:]
            if action == 'c':
                eval_a_afficher = Utils.get_evaluations(self.auteur_en_cours, id)
                self.afficher_evaluations(eval_a_afficher)
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.gestion_des_evaluations()
            elif action == 's':
                Utils.supprimer_evaluation(id)
                print("Evaluation supprimée")
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.gestion_des_evaluations()
            else:
                print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
                input()
                self.menu_contenus_en_cours()

    # Fonction d'affichage des évaluations (identique à l'affichage du détail)
    def afficher_evaluations(self, evaluations):
        for elt in evaluations:
            print("n°", elt["idEval"], " - date", elt["date"], " - contenus : ", end='')
            for i in range(len(elt["contenu(s)"])):
                print(i + 1, " ", end='')
            print("\r")

    # Création d'une évaluation
    def creerEvaluation(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        # on charge tous les contenus présents
        questions = Utils.get_contenus_panier(self.auteur_en_cours)
        if len(questions) > 0:
            self.afficher_contenus_banque(questions)
        print("Nombre de contenus à ajouter : (entre 1 et ", Utils.get_max_id_contenus(),
              "), q pour revenir en arrière")
        choix = (input())
        questions = list()
        if choix == 'q':
            self.menu_des_actions()
        elif choix.isdigit():
            print(int(choix), "questions dans l'éval")
            # en fonction de la saisie précédente on invite l'utilisateur à entrer ses numéros de contenu
            for i in range(int(choix)):
                print("Contenu ", i + 1, ", donner l'id du contenu :")
                questions.append(int(input()))
            Utils.creer_evaluation(questions, self.auteur_en_cours)

    ## Fonction de gestion des mises à jour
    def menu_de_maj(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Actions disponibles : ")
        print("q : revenir au menu des actions")
        print("d : Consulter les mises à jour recues")
        print("p : Consulter les mises à jour proposées")
        choix = (input())
        if choix == 'q':
            self.menu_des_actions()
        if choix == 'd':
            self.gestion_maj_recues()
        if choix == 'p':
            os.system('clear')
            print("Bonjour ", self.auteur_en_cours)
            publications = Utils.get_demandes_pub(self.auteur_en_cours, True)
            print("Vous avez", publications.count(), " demandes de publication en cours")
            for pub in publications:
                id_pub = pub["id"]
                print("idDemandePublication : ", pub["id"], "auteur d'origine :", pub["auteurContenu"], "date : ",
                      pub["date"],
                      "etat : ", pub["etat"])
                if pub["etat"] == "accepté":
                    print("Votre publication a été acceptée. Le contenu tiers correspondant a été mis à jours")
                    Utils.supprimer_publication(pub["id"])
                    # Utils.supprimer_contenu_en_cours(Utils.get_id_contenu_en_cours_associe_a_une_publication(pub['id']))
                if pub["etat"] == "refus":
                    print("Actions possibles : ")
                    print("n : creer un nouveau contenu a partir de celui ci")
                    print("s : supprimer le contenu")
                    print("c : (non disponible) conserver le contenu en l'état")
                    print("q : remettre ce choix à plus tard")
                    choix = input()
                    print("Le choix que je fais : ", choix)
                    if choix == 'n':
                        id_en_cours = Utils.get_id_contenu_en_cours_associe_a_une_publication(id_pub)
                        print("L'id du contenu en cours est : ", id_en_cours)
                        contenu_associe = Utils.get_id_contenu_associe_a_un_en_cours(id_en_cours)
                        chemin = Utils.get_chemin_du_contenu(contenu_associe)

                        Utils.creer_nouveau_contenu(chemin,
                                                    self.auteur_en_cours, id_pub)
                        if Utils.is_tiers_auteur(self.auteur_en_cours, contenu_associe):
                            versionFavori = Utils.get_version_tiers_avec_id(contenu_associe, self.auteur_en_cours)
                            Utils.supprimer_tiers(contenu_associe, self.auteur_en_cours, versionFavori)
                            print("Vous venez de créer un nouveau contenu")
                        Utils.supprimer_publication(pub["id"])
                        sleep(2)
                        self.menu_contenus_personnels()
                    elif choix == 's':
                        Utils.supprimer_contenu_en_cours(
                            Utils.get_id_contenu_en_cours_associe_a_une_publication(pub["id"]))
                        Utils.supprimer_publication(pub["id"])
                    elif choix == 'q':
                        self.menu_de_maj()
            print("Appuyer sur q pour revenir en arrière : ")
            input()
            self.menu_de_maj()
        else:
            print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
            input()
            self.menu_des_actions()

        ## listing de toutes les mises a jour possibles pour les tiers d'un auteur
        # @param auteur l'auteur en cours

    def liste_maj_tiers(self, auteur):
        # on cherche toutes les versions en cours dans les tiers et on compare avec celles de la banque
        # Trouver un moyen de sauvegarder le fait qu'une maj ait été refusée.
        tiers = Utils.get_contenus_tiers(auteur)
        for (id, version) in tiers:
            versionCourante = Utils.get_version_courante(id["contenu"])
            if version["version"] < versionCourante:
                if not Utils.is_maj_refusee(auteur, id["contenu"], versionCourante):
                    print("Contenu : ", id["contenu"], " version actuelle : ", version["version"], "version maj : ",
                          versionCourante)
                    print("Mise à jour possible")
                    print(
                        "Appuyer sur c pour consulter le détail de la mise à jour du contenu")
                    choix = input()
                    if choix == 'c':
                        Utils.changer_version(id["contenu"], 0, "master")
                        Utils.changer_version(id["contenu"], Utils.get_version_courante(id["contenu"]))
                        print("Détail de la maj disponible pour le contenu : ")
                        Utils.consulter_un_contenu(id["contenu"], self.auteur_en_cours)
                        print(
                            "Appuyer sur o pour accepter cette maj, sur n pour la refuser ou sur q pour revenir au menu des actions : ")

                        if choix == 'o':
                            Utils.maj_tiers(id["contenu"], versionCourante, auteur)
                            print("Mise à jour effectuée")
                            print("appuyez sur q pour revenir au menu des actions")
                            input()
                            self.menu_des_actions()
                        elif choix == 'n':
                            Utils.maj_tiers(id["contenu"], versionCourante, auteur, True)
                            print("Mise à jour refusée")
                            print("appuyez sur q pour revenir au menu des actions")
                            input()
                            self.menu_des_actions()
                        else:
                            self.menu_des_actions()

    ## gestion des mises à jour de contenu recues
    def gestion_maj_recues(self):

        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Vous aurez, ici, les maj possibles de contenu perso et de contenu tiers")
        print("Actions disponibles : ")
        print("q : revenir au menu des mises à jour")
        print("p : Consulter les mises à jour liées au contenus persos")
        print("t : Consulter les mises à jour liées au contenus tiers")
        choix = (input())
        if choix == 'q':
            self.menu_de_maj()
        elif choix == 'p':
            # mise à jour de contenus personnels
            os.system('clear')
            print("Bonjour ", self.auteur_en_cours)
            publications = Utils.get_demandes_pub(self.auteur_en_cours, False)
            print("Vous avez ", publications.count(), "mises à jour disponibles")
            if publications.count() > 0:
                for pub in publications:
                    etat = pub["etat"]
                    # pour raison de simplicité, les demandes de publication refusées sont invisibles (dans un futur proche elle seront visibles mais non interactives)
                    if etat != "refus":
                        print("Auteur qui fait la demande : ", pub["auteurDemande"], "idDemandePublication : ",
                              pub["id"], "date : ", pub["date"])
                        print("Actions possibles : ")
                        print("c : consulter la demande de publication")
                        print("o : accepter la demande de publication")
                        print("n : refuser la demande de publication")
                        print("q : revenir en arriere")
                        print("Entrer l'id du contenu, puis une lettre d'action (ou directement q pour quitter)")

                        choix = (input())
                        if choix == 'q':
                            self.menu_de_maj()
                        elif len(choix) > 1:
                            id = int(choix[:len(choix) - 1])
                            action = choix[len(choix) - 1:]
                            if action == 'o' or action == 'n':
                                Utils.gerer_demande_pub(id, action, Utils.get_auteur_demande_publication(id))
                                if action == 'o':
                                    decision = "acceptée"
                                else:
                                    decision = "refusée"

                                print("La publication a été", decision)
                                print("Appuyer sur q pour revenir en arrière : ")
                                input()
                                self.gestion_maj_recues()
                            elif action == 'c':
                                Utils.changer_version(id, 0, Utils.get_branche_contenu_en_cours(id))
                                print("Voici le contenu associé à la demande de publication : ")
                                branche_contenu_en_cours = Utils.get_branche_contenu_en_cours(id)
                                Utils.changer_version(Utils.get_id_contenu_associe_a_un_en_cours(id), 0,
                                                      branche_contenu_en_cours)
                                Utils.consulter_un_contenu(id, self.auteur_en_cours)
                                print("Appuyer sur q pour revenir en arrière : ")
                                input()
                                Utils.detruire_fichier_tmp(id, self.auteur_en_cours)
                                self.gestion_maj_recues()
                            else:
                                print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
                                input()
                                self.gestion_maj_recues()
            else:
                print("Appuyer sur q pour revenir en arrière : ")
                input()
                self.gestion_maj_recues()


        elif choix == 't':
            # mise à jour de contenus favoris
            os.system('clear')
            print("Bonjour ", self.auteur_en_cours)
            print(
                f"Vous possédez {len(Utils.get_contenus_tiers(self.auteur_en_cours))} contenus tiers potentiellement mettables "
                f"à jour : ")

            nbre_favoris = len(Utils.get_contenus_tiers(self.auteur_en_cours))
            print("L'auteur possède ", nbre_favoris, " favoris")
            if nbre_favoris > 0:
                Utils.liste_maj_tiers(self.auteur_en_cours)
                print("Appuyez sur q pour revenir en arriere")
                input()
                self.gestion_maj_recues()
            else:
                print("Vous n'avez aucun favori possédant une mise à jour, appuyez sur q pour revenir en arriere")
            input()
            self.gestion_maj_recues()

        else:
            print("Action inconnue, Appuyer sur q pour revenir en arrière : ")
            input()
            self.gestion_maj_recues()



    '''
    ##   Importer un fichier

    def import_fichier(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Selectionner le fichier à charger")
        print("1 : Contenu1")
        print("2 : Contenu2")
        print("3 : Revenir en arrière")
        print("Votre choix : ")
        choix = (input())
        if choix.isdigit():
            self.switchFichiers(int(choix))

    ##    En fonction du choix effectué dans importFichier, on charge le fichier choisi

    def switchFichiers(self, argument):
        if argument == 1 or argument == 2:
            Utils.ajouterContenu("Contenu" + str(argument), self.auteur_en_cours)
            self.consulterPanier()
        elif argument == 3:
            self.menu_des_actions()
        else:
            print("Fichier inexistant")

    ##    Consulter le panier (action 1)
    def consulterPanier(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        # 1. On charge les contenus "propres" de la banque
        questions = Utils.consulterContenu(self.auteur_en_cours, True)
        print(self.auteur_en_cours + " possede " + str(questions.count()) + " contenu(s)")
        if questions.count() > 0:
            self.afficherContenus(questions)
        # 1. On charge les contenus "mis en favori" de la banque

        print(
            f"Contenus mis en favori par l'auteur {self.auteur_en_cours} : {len(Utils.getFavoris(self.auteur_en_cours))}")

        if len(Utils.getFavoris(self.auteur_en_cours)):
            for (id, version) in Utils.getFavoris(self.auteur_en_cours):
                print("La question : ", int(id['contenu']), " et sa version", int(version['version']))
                self.afficherContenusFavoris(
                    Utils.getContenuavecIdEtVersion(int(id['contenu']), int(version['version'])),
                    int(version['version']))
        print("Appuyer sur q pour revenir en arriere")
        choix = (input())
        if choix == 'q':
            self.menu_des_actions()

    ##    Consulter la banque (action 2)
    def consulterBanque(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        # on charge tous les contenus n'appartenant pas à l'utilisateur (qu'il peut retrouver dans son panier)
        questions = Utils.consulterContenu(self.auteur_en_cours, False)
        print("La banque possède actuellement", questions.count(), " contenu(s)")
        if questions.count() > 0:
            self.afficherContenusBanque(questions)

            # on propose à l'utilisateur de mettre en favori les contenus de la banque
            print("Entrer l'id de la question à mettre en favori ou appuyer sur q pour revenir en arriere")
            choix = (input())
            if choix == 'q':
                self.menu_des_actions()
            elif choix.isdigit():
                print("Je veux favoriser la question ", choix, " et je suis l'auteur ", self.auteur_en_cours)
                Utils.mettreContenuEnFavori(choix, self.auteur_en_cours)
                self.consulterPanier()
            else:
                print("On t'a dit q ou un un chiffre sérieux :<")
        else:
            print("Appuyer sur q pour revenir en arriere")
            choix = (input())
            if choix == 'q':
                self.menu_des_actions()

    ##    Fonction d'affichage des contenus 'panier personnel'

    def afficherContenus(self, contenu):

        for elt in contenu:
            print("nom :", elt["fichier"], " - v", elt["versionEnCours"]["numero"], " - du",
                  elt["versionEnCours"]["date"])

    ##    Fonction d'affichage des contenus 'banque'
    def afficherContenusBanque(self, contenu):

        favoris = Utils.getFavoris(self.auteur_en_cours)
        is_fav = False
        # print("favoris : ", favoris)

        for elt in contenu:
            print("id :", elt["id"], "auteur :", elt["auteur"], " - nom :", elt["fichier"], " - v",
                  elt["versionEnCours"]["numero"], " - du",
                  elt["versionEnCours"]["date"], end='')
            is_fav = False

            for fac in favoris:
                if elt["id"] == fac[0]["contenu"]:
                    print(f' (* v{fac[1]["version"]})')
                    is_fav = True
            if not is_fav:
                print("\r")

    ##    Fonction d'affichage des contenus 'favoris'
    def afficherContenusFavoris(self, contenu, version):

        # print (contenu)

        print("id :", contenu["id"], "auteur :", contenu["auteur"], " - nom :", contenu["fichier"], " - v",
              version, " - du",
              contenu["versionEnCours"]["date"])

    ##    Fonction d'affichage des contenus 'en cours de modification'
    def afficherContenusEnCours(self, contenu):

        en_cours = Utils.getContenusEnCours(self.auteur_en_cours)

        print("Je veux afficher", en_cours.count(), "contenus en cours")

        for elt in en_cours:
            print("id Modif :", elt["idContenuEC"], "auteur original :", elt["auteur"], " - id Original :",
                  elt["reference"],
                  "version original", elt["version"], " date modif ", elt["date"])

    ##    Supprimer un contenu  (permet de dissocier son auteur) (action 4)

    def supprimerContenu(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        print("1. Supprimer un contenu personnel")
        print("2. Supprimer un favori")
        print("3. Revenir en arrière")

        choix = int(input())
        if choix == 1:
            self.supprimerContenuPersonnel()
        elif choix == 2:
            self.supprimerContenuFavori()
        else:
            self.menu_des_actions()

    ##    Supprimer un contenu - Fonction spécifique contenu personnel (action 4)

    def supprimerContenuPersonnel(self):
        # On charge les contenus de l'auteur en cours (si existants)
        questions = Utils.consulterContenu(self.auteur_en_cours, True)
        print(self.auteur_en_cours + " possede " + str(questions.count()) + " contenu(s)")
        if questions.count() > 0:
            self.afficherContenusBanque(questions)

        print("Entrer l'id du contenu à supprimer ou appuyer sur q pour revenir en arriere")
        choix = (input())
        if choix == 'q':
            self.supprimerContenu()

        # on charge la fonction de "suppression" d'un contenu en fonction de la saisie de l'utilisateur
        if choix.isdigit():
            print("Le contenu choisi a ", int(choix), "favoris liés")
            if Utils.existeEnFavori(int(choix)):
                Utils.supprimerContenu(int(choix))
                self.consulterPanier()
            else:
                Utils.aneantirContenu(int(choix))
                self.consulterPanier()

    ##    Supprimer un contenu - Fonction spécifique contenu favori (action 4)

    def supprimerContenuFavori(self):

        favoris = dict()
        print(self.auteur_en_cours, " possede ", len(Utils.getFavoris(self.auteur_en_cours)), " favori(s)")

        # On charge les contenus de l'auteur en cours (si existants)
        if len(Utils.getFavoris(self.auteur_en_cours)):
            for (id, version) in Utils.getFavoris(self.auteur_en_cours):
                print("La question : ", id["contenu"], " et sa version", version["version"])
                self.afficherContenusFavoris(Utils.getContenuavecIdEtVersion(id["contenu"], version["version"]),
                                             version["version"])
                favoris[id["contenu"]] = version["version"]

        print("Entrer l'id du contenu à supprimer ou appuyer sur q pour revenir en arriere")
        choix = (input())
        if choix == 'q':
            self.supprimerContenu()

        # on charge la fonction de "suppression" d'un contenu en fonction de la saisie de l'utilisateur
        if choix.isdigit():
            print("Le contenu choisi a ", int(choix), "favoris liés. Sa version associée est : ", favoris[int(choix)])
            Utils.supprimerFavori(int(choix), self.auteur_en_cours, favoris[int(choix)])
            print("Le favori ", int(choix), " a été supprimé")
            print("nombre : ", Utils.existeEnFavori(int(choix)))
            print("anonyme : ", Utils.isAnonyme(int(choix)))

            if Utils.existeEnFavori(int(choix)) and Utils.isAnonyme(int(choix)):
                Utils.aneantirContenu(int(choix))
                print("Le contenu ", int(choix), " a été définitivement supprimé")

    ##    Créer une evaluation (regroupement de contenu) (action 5)
    def creerEvaluation(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        # on charge tous les contenus présents
        questions = Utils.consulterTousLesContenu()
        if questions.count() > 0:
            self.afficherContenusBanque(questions)
        print("Nombre de contenus à ajouter : (entre 1 et ", Utils.getMaxIdContenus(),
              "), q pour revenir en arrière")
        choix = (input())

        questions = list()
        if choix == 'q':
            self.menu_des_actions()
        if choix.isdigit():
            print(int(choix), "questions dans l'éval")
            # en fonction de la saisie précédente on invite l'utilisateur à entrer ses numéros de contenu
            for i in range(int(choix)):
                print("Contenu ", i + 1, ", donner l'id du contenu :")
                questions.append(int(input()))
            print("Contenus(s) choisi(s) : ", questions)
            Utils.creerEvaluation(questions, self.auteur_en_cours)
            self.consulterEvaluations()

    ##    Consulter les évaluations pour l'auteur en cours (action 6)
    def consulterEvaluations(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        print("L'auteur ", self.auteur_en_cours, " a ", Utils.getEvaluations(self.auteur_en_cours).count(),
              " evaluations")
        self.afficherEvaluations(Utils.getEvaluations(self.auteur_en_cours))
        print("Entrer un id pour supprimer une évaluation ou Appuyer sur q pour revenir en arriere")
        choix = (input())
        if choix == 'q':
            self.menu_des_actions()
        if choix.isdigit():
            # print("Je veux modifier la question : ", choix)
            Utils.supprimerEvaluation(choix)
            print("Contenu supprimé")
            self.consulterEvaluations()

    ##    Afficher le détail des évaluations d'un auteur
    def afficherEvaluations(self, evaluations):
        for elt in evaluations:
            print("n°", elt["idEval"], " - date", elt["date"], " - contenus : ", end='')
            for i in range(len(elt["contenu(s)"])):
                print(i + 1, " ", end='')
            print("\r")

    ##    Afficher le détail des évaluations d'un auteur (action 7)
  

    ## Contenus en cours de modification. Seront par la suite intégrés au panier
    def consulterEnCours(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        contenus = Utils.getContenusEnCours(self.auteur_en_cours)
        print("Vous avez ", contenus.count(), "contenu(s) en cours de modification")
        if contenus.count() > 0:
            self.afficherContenusEnCours(contenus)
        print("Entrer l'id du contenu en cours, puis une lettre d'action (ou directement q pour quitter)")
        print("c pour consulter le contenu")
        print("m pour modifier le contenu")
        print("s pour supprimer le contenu")
        print("v pour valider la modification du contenu (sous réserve)")
        print("n pour créer un nouveau contenu")

        choix = input()

        id = 0
        action = ""

        if choix == "q":
            self.menu_des_actions()
        if len(choix) < 2 or choix[len(choix) - 1:].isdigit():
            self.consulterEnCours()
        else:
            id = int(choix[:len(choix) - 1])
            action = choix[len(choix) - 1:]

            print("id :", id)
            print("action :", action)
            print("action c :", action == 'c')

        idContenu = Utils.getIdContenuAssocieAUnEnCours(int(id))

        print("id contenu associé : ", idContenu)

        # affiche le contenu courant du fichier
        if action == 'c':
            print("je suis dans action c")

            Utils.changerVersion(idContenu, 0, Utils.getBrancheContenuEnCours(idContenu))
            # exit(0)
            Utils.affichage(Utils.getCheminDuContenu(idContenu))
            # print("Uoi")

        elif action == 'm':
            Utils.changerVersion(idContenu, 0, Utils.getBrancheContenuEnCours(idContenu))
            Utils.modifierContenu(idContenu, self.auteur_en_cours, True)
            Utils.affichage(Utils.getCheminDuContenu(idContenu))
        elif action == 's':
            Utils.supprimerContenuEnCours(int(id))
        elif action == 'v':
            self.validerModification(int(id))
            Utils.supprimerContenuEnCours(int(id))

        elif action == 'n':
            contenu_associe = Utils.getIdContenuAssocieAUnEnCours(int(id))
            chemin = Utils.getCheminDuContenu(contenu_associe)

            Utils.creerNouveauContenu(chemin,
                                      self.auteur_en_cours, id)
            if Utils.isFavoriDeAuteur(self.auteur_en_cours, contenu_associe):
                versionFavori = Utils.getVersionFavoriById(contenu_associe, self.auteur_en_cours)
                Utils.supprimerFavori(contenu_associe, self.auteur_en_cours, versionFavori)
            self.consulterPanier()
        elif action == 'q':
            self.menu_des_actions()

    ## changement de version d'un contenu OU demande de publication à l'auteur d'origine

    def validerModification(self, idContenuEnCours):

        # on récupère l'auteur et l'id du contenu "de base" associé à la modif
        auteur = Utils.getAuteurContenuEnCours(idContenuEnCours)
        idContenu = Utils.getIdContenuAssocieAUnEnCours(idContenuEnCours)
        branche = Utils.getBrancheContenuEnCours(idContenuEnCours)

        print("L'auteur en cours est : ", self.auteur_en_cours)
        print("L'auteur de base est : ", auteur)

        if auteur == self.auteur_en_cours:
            print("Modification directe d'un auteur")
            chemin = Utils.getCheminDuContenu(idContenu)
            Utils.majContenu(chemin, idContenu, branche)
        else:
            print("Modification indirecte -> demande de publication")
            print("Je demande à l'auteur ", auteur, "de valider ma demande de proposition")
            Utils.demandePublication(idContenu, idContenuEnCours, self.auteur_en_cours, auteur)
            self.menu_des_actions()

    ## Naviguer entre différentes versions d'un contenu - Action 8
    def naviguerContenu(self):
        print("Cette fonction servira à consulter différentes versions d'un contenu")
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)

        # 1. On charge les contenus "propres" de la banque
        questions = Utils.consulterContenu(self.auteur_en_cours, True)
        nbreQuestion = questions.count()
        print(self.auteur_en_cours + " possede " + str(nbreQuestion) + " contenu(s)")
        if questions.count() > 0:
            self.afficherContenusBanque(questions)
        # 1. On charge les contenus "mis en favori" de la banque

        print(
            f"Contenus mis en favori par l'auteur {self.auteur_en_cours} : {len(Utils.getFavoris(self.auteur_en_cours))}")
        nbreFavoris = len(Utils.getFavoris(self.auteur_en_cours))
        if len(Utils.getFavoris(self.auteur_en_cours)):
            for (id, version) in Utils.getFavoris(self.auteur_en_cours):
                print("La question : ", int(id['contenu']), " et sa version", int(version['version']))
                self.afficherContenusFavoris(
                    Utils.getContenuavecIdEtVersion(int(id['contenu']), int(version['version'])),
                    int(version['version']))
        if nbreFavoris > 0 or nbreQuestion > 0:
            print("Entrer le numero de contenu désiré (ou q pour quitter)")
            choix = input()
            if choix == 'q':
                self.menu_des_actions()
            if choix.isdigit():
                print("La question qui m'intéresse est la : ", int(choix))
                print("Cette question en est à la version : ", Utils.getVersionCourante(int(choix)))
                if Utils.getVersionCourante(int(choix)) == 1:
                    print("Aucun choix, j'affiche juste la version en cours")
                    Utils.affichage(Utils.getCheminDuContenu(int(choix)))
                else:
                    contenu = int(choix)
                    print("Je choisis la version que je veux : (entre 1 et", Utils.getVersionCourante(int(choix)), ")")
                    choix = int(input())
                    print("Je veux charger la version ", choix)
                    # commitVersion = Utils.getCommitPourUneVersion(choix, contenu)
                    Utils.changerVersion(contenu, choix)

    ## Gérer les demandes de publication emises et recues - Action 11
    def gererDemandesPublication(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("1. Demandes de publication emises")
        print("2. Demandes de publication reçues")
        print("3. Revenir en arrière")

        choix = int(input())
        if choix == 1:
            contributions = Utils.getDemandesPub(self.auteur_en_cours)
            print("Je veux afficher les contributions emises, j'ai ", contributions.count(), "contributions")
            if contributions.count() > 0:
                self.afficherDdePublications(contributions, True)
            else:
                print("Vous n'avez aucune demande de contribution emise, appuyez sur q pour revenir en arriere")
                input()
                self.gererDemandesPublication()
        elif choix == 2:
            contributions = Utils.getDemandesPub(self.auteur_en_cours, False)
            print("Je veux afficher les contributions recues, j'ai ", contributions.count(), "contributions")
            if contributions.count() > 0:
                self.afficherDdePublications(contributions, False)
            else:
                print("Vous n'avez aucune demande de contribution emise, appuyez sur q pour revenir en arriere")
                input()
                self.gererDemandesPublication()
        elif choix == 3:
            self.menu_des_actions()

    ## Affichage des demandes de publication
    # @param emetteur -> l'auteur est le demandeur de la publication si True, et le réceptionnaire si False
    def afficherDdePublications(self, publications, emetteur):
        if not emetteur:
            texte = "auteur demandeur : "
            for pub in publications:
                etat = pub["etat"]
                # pour raison de simplicité, les demandes de publication refusées sont invisibles (dans un futur proche elle seront visibles mais non interactives)
                if etat != "refus":
                    print(texte, pub["auteurDemande"], "idDemandePublication : ", pub["id"], "date : ", pub["date"])
            print("Entrer l'id de la publication puis O ou N pour accepter ou refuser la demande")
            choix = input()
            num_contenu = choix[0:len(choix) - 1]
            choix = choix[len(choix) - 1:]
            Utils.gererDemandePub(num_contenu, choix)
        else:
            texte = "auteur source : "
            for pub in publications:
                id_pub = pub["id"]
                print(texte, pub["auteurContenu"], "idDemandePublication : ", pub["id"], "date : ", pub["date"],
                      "etat : ", pub["etat"])
                if pub["etat"] == "refus":
                    print("Actions possibles : ")
                    print("n : creer un nouveau contenu a partir de celui ci")
                    print("s : supprimer le contenu")
                    print("q : remettre ce choix à plus tard")
                    choix = input()
                    if choix == 'n':
                        id_en_cours = Utils.getIdContenuEnCoursAssocieAUnePublication(id_pub)
                        contenu_associe = Utils.getIdContenuAssocieAUnEnCours(id_en_cours)
                        chemin = Utils.getCheminDuContenu(contenu_associe)

                        Utils.creerNouveauContenu(chemin,
                                                  self.auteur_en_cours, id_pub)
                        if Utils.isFavoriDeAuteur(self.auteur_en_cours, contenu_associe):
                            versionFavori = Utils.getVersionFavoriById(contenu_associe, self.auteur_en_cours)
                            Utils.supprimerFavori(contenu_associe, self.auteur_en_cours, versionFavori)
                        self.consulterPanier()
                    elif choix == 's':
                        Utils.supprimerContenuEnCours(Utils.getIdContenuEnCoursAssocieAUnePublication(pub["id"]))
                    elif choix == 'q':
                        self.menu_des_actions()

    ## Observer les possibilités de mettre à jour les favoris - Action 12
    def majFavoris(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        nbreFavoris = len(Utils.getFavoris(self.auteur_en_cours))
        print("L'auteur possède ", nbreFavoris, " favoris")
        if nbreFavoris > 0:
            Utils.listeMajFavoris(self.auteur_en_cours)
        else:
            print("Vous n'avez aucun favori, appuyez sur q pour revenir en arriere")
            input()
            self.menu_des_actions()

    ## rechercher un contenu dans la banque
    def rechercherContenu(self):
        os.system('clear')
        print("Bonjour ", self.auteur_en_cours)
        print("Bienvenue dans la fonction de recherche")
        print("Pour le moment, la recherche ne marche que pour la banque")
        print("Dans la future application, une recherche 'panier' sera implémentée")
        print("Choisir parmi les modes de recherche disponibles : (ou q pour quitter)   ")
        print("1. Recherche par auteur")
        print("2. Recherche par date")
        print("3. Recherche par note")
        print("4. Recherche par tag")
        print("5. Recherche sur le contenu")
        choix = input()
        if choix == 'q':
            self.menu_des_actions()
        elif choix.isdigit():
            self.gererRecherche(int(choix))

    ## gérer la recherche en fonction du type choisi
    def gererRecherche(self, choix):
        if choix == 1:
            print("Vous avez choisi une recherche par auteur")
            print("Entrez le nom de l'auteur : ")
            choix = input()
            Utils.rechercheSurContenu(1, choix)
        elif choix == 2:
            print("Vous avez choisi une recherche par date")
            print("Entrez la date (format JJ/MM/YY) : ")
            choix = input()
            Utils.rechercheSurContenu(2, choix)
        elif choix == 3:
            print("Vous avez choisi une recherche par note")
            print("Entrez la note : ")
            choix = input()
            Utils.rechercheSurContenu(3, choix)
        elif choix == 4:
            print("Vous avez choisi une recherche par tag")
            print("Entrer un tag : ")
            choix = input()
            Utils.rechercheSurContenu(4, choix)
        elif choix == 5:
            print("Vous avez choisi une recherche sur le contenu")
            print("Entrer un mot : ")
            choix = input()
            Utils.rechercheSurContenu(5, choix)
    '''
